@@ -19,6 +19,15 @@ Ext.grid.FTWTableGroupingView = Ext.extend(Ext.grid.GroupingView, {
     this.beforeMenuShow(); // Make sure the checkboxes get properly set when changing groups
     this.refresh();
     this.grid.store.reload();
+  },
+  // private
+  onColumnWidthUpdated : function(col, w, tw){
+      Ext.grid.GroupingView.superclass.onColumnWidthUpdated.call(this, col, w, tw);
+      this.updateGroupWidths();
+      //set width of the header div to the same value as the table
+      //we need a few extra pixel to make the resizable handle draggable
+      var inner_width = $('.x-grid3-header table').width() + 5;
+      $('.x-grid3-header').width(inner_width);
   }
 });
 
@@ -133,6 +142,16 @@ Ext.state.FTWPersistentProvider = Ext.extend(Ext.state.Provider, {
           }});
 
           var columns = store.reader.meta.columns;
+          // workaround to make the last column resizeable in IE - add an
+          // empty column
+          columns.push({
+              dataIndex: "dummy",
+              header: "",
+              id: "dummy",
+              menuDisabled: true,
+              sortable: false,
+              width: 1});
+          // Set up the ColumnModel
 
           // Set up the ColumnModel
           var cm = new Ext.grid.ColumnModel({
@@ -277,7 +296,8 @@ Ext.state.FTWPersistentProvider = Ext.extend(Ext.state.Provider, {
                   //enable horizontal scrolling
                   $('.x-grid3-viewport').css('overflow', 'auto');
                   //set width of the header div to the same value as the table
-                  var inner_width = $('.x-grid3-header table').width();
+                  //we need a few extra pixel to make the resizable handle draggable
+                  var inner_width = $('.x-grid3-header table').width() + 5;
                   $('.x-grid3-header').width(inner_width);
                 }
 
@@ -294,7 +314,7 @@ Ext.state.FTWPersistentProvider = Ext.extend(Ext.state.Provider, {
                 var sm = grid.getSelectionModel();
                 $("input[checked=checked]").each(function(i, e) {
                     sm.selectRow($(e).closest(".x-grid3-row").index(), 1);
-                })
+                });
                 
                 /* Hide the "No contents" element if we have
                    no contents */
